@@ -4,11 +4,11 @@
  *	  interface routines for the postgres GiST index access method.
  *
  *
- * Portions Copyright (c) 1996-2006, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2008, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  * IDENTIFICATION
- *	  $PostgreSQL: pgsql/src/backend/access/gist/gistvacuum.c,v 1.28 2006/10/04 00:29:48 momjian Exp $
+ *	  $PostgreSQL: pgsql/src/backend/access/gist/gistvacuum.c,v 1.34 2008/01/01 19:45:46 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -35,6 +35,7 @@ typedef struct
 	Relation	index;
 	MemoryContext opCtx;
 	GistBulkDeleteResult *result;
+	BufferAccessStrategy strategy;
 } GistVacuum;
 
 typedef struct
@@ -83,7 +84,7 @@ gistDeleteSubtree(GistVacuum *gv, BlockNumber blkno)
 	Buffer		buffer;
 	Page		page;
 
-	buffer = ReadBuffer(gv->index, blkno);
+	buffer = ReadBufferWithStrategy(gv->index, blkno, gv->strategy);
 	LockBuffer(buffer, GIST_EXCLUSIVE);
 	page = (Page) BufferGetPage(buffer);
 
@@ -133,7 +134,7 @@ gistDeleteSubtree(GistVacuum *gv, BlockNumber blkno)
 		PageSetTLI(page, ThisTimeLineID);
 	}
 	else
-		PageSetLSN(page, GetXLogRecPtrForTemp());
+		PageSetLSN(page, XLogRecPtrForTemp);
 
 	END_CRIT_SECTION();
 
@@ -200,7 +201,7 @@ vacuumSplitPage(GistVacuum *gv, Page tempPage, Buffer buffer, IndexTuple *addon,
 		data = (char *) (ptr->list);
 		for (i = 0; i < ptr->block.num; i++)
 		{
-			if (PageAddItem(ptr->page, (Item) data, IndexTupleSize((IndexTuple) data), i + FirstOffsetNumber, LP_USED) == InvalidOffsetNumber)
+			if (PageAddItem(ptr->page, (Item) data, IndexTupleSize((IndexTuple) data), i + FirstOffsetNumber, false, false) == InvalidOffsetNumber)
 				elog(ERROR, "failed to add item to index page in \"%s\"", RelationGetRelationName(gv->index));
 			data += IndexTupleSize((IndexTuple) data);
 		}
@@ -252,7 +253,7 @@ vacuumSplitPage(GistVacuum *gv, Page tempPage, Buffer buffer, IndexTuple *addon,
 	else
 	{
 		for (ptr = dist; ptr; ptr = ptr->next)
-			PageSetLSN(BufferGetPage(ptr->buffer), GetXLogRecPtrForTemp());
+			PageSetLSN(BufferGetPage(ptr->buffer), XLogRecPtrForTemp);
 	}
 
 	for (ptr = dist; ptr; ptr = ptr->next)
@@ -303,7 +304,7 @@ gistVacuumUpdate(GistVacuum *gv, BlockNumber blkno, bool needunion)
 
 	vacuum_delay_point();
 
-	buffer = ReadBuffer(gv->index, blkno);
+	buffer = ReadBufferWithStrategy(gv->index, blkno, gv->strategy);
 	LockBuffer(buffer, GIST_EXCLUSIVE);
 	gistcheckpage(gv->index, buffer);
 	page = (Page) BufferGetPage(buffer);
@@ -466,7 +467,7 @@ gistVacuumUpdate(GistVacuum *gv, BlockNumber blkno, bool needunion)
 				pfree(rdata);
 			}
 			else
-				PageSetLSN(page, GetXLogRecPtrForTemp());
+				PageSetLSN(page, XLogRecPtrForTemp);
 		}
 
 		END_CRIT_SECTION();
@@ -550,6 +551,7 @@ gistvacuumcleanup(PG_FUNCTION_ARGS)
 		initGISTstate(&(gv.giststate), rel);
 		gv.opCtx = createTempGistContext();
 		gv.result = stats;
+		gv.strategy = info->strategy;
 
 		/* walk through the entire index for update tuples */
 		res = gistVacuumUpdate(&gv, GIST_ROOT_BLKNO, false);
@@ -600,7 +602,7 @@ gistvacuumcleanup(PG_FUNCTION_ARGS)
 
 		vacuum_delay_point();
 
-		buffer = ReadBuffer(rel, blkno);
+		buffer = ReadBufferWithStrategy(rel, blkno, info->strategy);
 		LockBuffer(buffer, GIST_SHARE);
 		page = (Page) BufferGetPage(buffer);
 
@@ -704,7 +706,7 @@ gistbulkdelete(PG_FUNCTION_ARGS)
 
 	while (stack)
 	{
-		Buffer		buffer = ReadBuffer(rel, stack->blkno);
+		Buffer		buffer = ReadBufferWithStrategy(rel, stack->blkno, info->strategy);
 		Page		page;
 		OffsetNumber i,
 					maxoff;
@@ -789,7 +791,7 @@ gistbulkdelete(PG_FUNCTION_ARGS)
 					pfree(rdata);
 				}
 				else
-					PageSetLSN(page, GetXLogRecPtrForTemp());
+					PageSetLSN(page, XLogRecPtrForTemp);
 
 				END_CRIT_SECTION();
 			}
