@@ -4,24 +4,16 @@
  *	  this is a simple doubly linked list implementation
  *	  the elements of the lists are void*
  *
- * Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2008, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql-server/src/backend/lib/dllist.c,v 1.25 2002/06/20 20:29:28 momjian Exp $
+ *	  $PostgreSQL: pgsql/src/backend/lib/dllist.c,v 1.36 2008/01/01 19:45:49 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
-
-/* can be used in frontend or backend */
-#ifdef FRONTEND
-#include "postgres_fe.h"
-/* No assert checks in frontend ... */
-#define Assert(condition)
-#else
 #include "postgres.h"
-#endif
 
 #include "lib/dllist.h"
 
@@ -31,18 +23,10 @@ DLNewList(void)
 {
 	Dllist	   *l;
 
-	l = (Dllist *) malloc(sizeof(Dllist));
-	if (l == NULL)
-	{
-#ifdef FRONTEND
-		fprintf(stderr, "Memory exhausted in DLNewList\n");
-		exit(1);
-#else
-		elog(ERROR, "Memory exhausted in DLNewList");
-#endif
-	}
-	l->dll_head = 0;
-	l->dll_tail = 0;
+	l = (Dllist *) palloc(sizeof(Dllist));
+
+	l->dll_head = NULL;
+	l->dll_tail = NULL;
 
 	return l;
 }
@@ -50,8 +34,8 @@ DLNewList(void)
 void
 DLInitList(Dllist *list)
 {
-	list->dll_head = 0;
-	list->dll_tail = 0;
+	list->dll_head = NULL;
+	list->dll_tail = NULL;
 }
 
 /*
@@ -63,10 +47,10 @@ DLFreeList(Dllist *list)
 {
 	Dlelem	   *curr;
 
-	while ((curr = DLRemHead(list)) != 0)
-		free(curr);
+	while ((curr = DLRemHead(list)) != NULL)
+		pfree(curr);
 
-	free(list);
+	pfree(list);
 }
 
 Dlelem *
@@ -74,36 +58,28 @@ DLNewElem(void *val)
 {
 	Dlelem	   *e;
 
-	e = (Dlelem *) malloc(sizeof(Dlelem));
-	if (e == NULL)
-	{
-#ifdef FRONTEND
-		fprintf(stderr, "Memory exhausted in DLNewElem\n");
-		exit(1);
-#else
-		elog(ERROR, "Memory exhausted in DLNewElem");
-#endif
-	}
-	e->dle_next = 0;
-	e->dle_prev = 0;
+	e = (Dlelem *) palloc(sizeof(Dlelem));
+
+	e->dle_next = NULL;
+	e->dle_prev = NULL;
 	e->dle_val = val;
-	e->dle_list = 0;
+	e->dle_list = NULL;
 	return e;
 }
 
 void
 DLInitElem(Dlelem *e, void *val)
 {
-	e->dle_next = 0;
-	e->dle_prev = 0;
+	e->dle_next = NULL;
+	e->dle_prev = NULL;
 	e->dle_val = val;
-	e->dle_list = 0;
+	e->dle_list = NULL;
 }
 
 void
 DLFreeElem(Dlelem *e)
 {
-	free(e);
+	pfree(e);
 }
 
 void
@@ -128,9 +104,9 @@ DLRemove(Dlelem *e)
 		l->dll_tail = e->dle_prev;
 	}
 
-	e->dle_next = 0;
-	e->dle_prev = 0;
-	e->dle_list = 0;
+	e->dle_next = NULL;
+	e->dle_prev = NULL;
+	e->dle_list = NULL;
 }
 
 void
@@ -141,10 +117,10 @@ DLAddHead(Dllist *l, Dlelem *e)
 	if (l->dll_head)
 		l->dll_head->dle_prev = e;
 	e->dle_next = l->dll_head;
-	e->dle_prev = 0;
+	e->dle_prev = NULL;
 	l->dll_head = e;
 
-	if (l->dll_tail == 0)		/* if this is first element added */
+	if (l->dll_tail == NULL)	/* if this is first element added */
 		l->dll_tail = e;
 }
 
@@ -156,10 +132,10 @@ DLAddTail(Dllist *l, Dlelem *e)
 	if (l->dll_tail)
 		l->dll_tail->dle_next = e;
 	e->dle_prev = l->dll_tail;
-	e->dle_next = 0;
+	e->dle_next = NULL;
 	l->dll_tail = e;
 
-	if (l->dll_head == 0)		/* if this is first element added */
+	if (l->dll_head == NULL)	/* if this is first element added */
 		l->dll_head = e;
 }
 
@@ -169,19 +145,19 @@ DLRemHead(Dllist *l)
 	/* remove and return the head */
 	Dlelem	   *result = l->dll_head;
 
-	if (result == 0)
+	if (result == NULL)
 		return result;
 
 	if (result->dle_next)
-		result->dle_next->dle_prev = 0;
+		result->dle_next->dle_prev = NULL;
 
 	l->dll_head = result->dle_next;
 
 	if (result == l->dll_tail)	/* if the head is also the tail */
-		l->dll_tail = 0;
+		l->dll_tail = NULL;
 
-	result->dle_next = 0;
-	result->dle_list = 0;
+	result->dle_next = NULL;
+	result->dle_list = NULL;
 
 	return result;
 }
@@ -192,19 +168,19 @@ DLRemTail(Dllist *l)
 	/* remove and return the tail */
 	Dlelem	   *result = l->dll_tail;
 
-	if (result == 0)
+	if (result == NULL)
 		return result;
 
 	if (result->dle_prev)
-		result->dle_prev->dle_next = 0;
+		result->dle_prev->dle_next = NULL;
 
 	l->dll_tail = result->dle_prev;
 
 	if (result == l->dll_head)	/* if the tail is also the head */
-		l->dll_head = 0;
+		l->dll_head = NULL;
 
-	result->dle_prev = 0;
-	result->dle_list = 0;
+	result->dle_prev = NULL;
+	result->dle_list = NULL;
 
 	return result;
 }
@@ -218,7 +194,7 @@ DLMoveToFront(Dlelem *e)
 	if (l->dll_head == e)
 		return;					/* Fast path if already at front */
 
-	Assert(e->dle_prev != 0);	/* since it's not the head */
+	Assert(e->dle_prev != NULL);	/* since it's not the head */
 	e->dle_prev->dle_next = e->dle_next;
 
 	if (e->dle_next)
@@ -232,7 +208,7 @@ DLMoveToFront(Dlelem *e)
 
 	l->dll_head->dle_prev = e;
 	e->dle_next = l->dll_head;
-	e->dle_prev = 0;
+	e->dle_prev = NULL;
 	l->dll_head = e;
 	/* We need not check dll_tail, since there must have been > 1 entry */
 }
