@@ -46,17 +46,13 @@ Datum
 namein(PG_FUNCTION_ARGS)
 {
 	char	   *s = PG_GETARG_CSTRING(0);
-	Name		result;
+	NameData   *result;
 	int			len;
 
 	len = strlen(s);
+	len = pg_mbcliplen(s, len, NAMEDATALEN - 1);
 
-	/* Truncate oversize input */
-	if (len >= NAMEDATALEN)
-		len = pg_mbcliplen(s, len, NAMEDATALEN - 1);
-
-	/* We use palloc0 here to ensure result is zero-padded */
-	result = (Name) palloc0(NAMEDATALEN);
+	result = (NameData *) palloc0(NAMEDATALEN);
 	memcpy(NameStr(*result), s, len);
 
 	PG_RETURN_NAME(result);
